package main

import (
	"context"
	"net/http/httptest"
	"net/url"
	"strings"
	"testing"

	"git.c3pb.de/gbe/invinoveritas/log"
	"git.c3pb.de/gbe/invinoveritas/vino"
)

type testLogger struct {
	t *testing.T
}

func (tl testLogger) Log(vals ...interface{}) error {
	tl.t.Log(vals...)
	return nil
}

type dummyStorage struct{}

func (d dummyStorage) Store(ctx context.Context, v *vino.Vino) error {
	return nil
}

func (d dummyStorage) StoreComment(ctx context.Context, v *vino.Vino, txt string) error {
	return nil
}

func (d dummyStorage) DeleteComment(ctx context.Context, id int) error {
	return nil
}

func (d dummyStorage) DeleteVino(ctx context.Context, id int) error {
	return nil
}

func TestHandler_Index_Add(t *testing.T) {
	w := httptest.NewRecorder()

	data := make(url.Values)
	data.Set("name", "unit-test")

	r := httptest.NewRequest("POST", "/add", strings.NewReader(data.Encode()))
	r.Header.Set("Content-Type", "application/x-www-form-urlencoded")

	var h Handler

	logger := testLogger{t}

	hdlr := log.Request(h.index(), logger)
	hdlr.ServeHTTP(w, r)

	// We want a redirect to the index after storing something
	if w.Code != 303 {
		t.Error("unexpected HTTP status code:", w.Code)
	}
}
