package session

import (
	"context"
	"testing"

	"git.c3pb.de/gbe/invinoveritas/storage"
	"git.c3pb.de/gbe/invinoveritas/storage/query"
	_ "modernc.org/sqlite"
)

func assertNoError(t *testing.T, err error) {
	if err != nil {
		t.Fatal("unexpected error:", err)
	}
}

type testLog struct {
	t *testing.T
}

func (t testLog) Log(p ...interface{}) error {
	t.t.Log(p...)
	return nil
}

func TestHashPassword(t *testing.T) {
	ctx := context.Background()

	db, err := storage.Open(ctx, ":memory:", testLog{t: t})
	if err != nil {
		t.Fatal("unexpected error:", err)
	}
	defer db.Close()

	q := query.New(db)

	err = q.InsertSalt(ctx, "unit-test")
	assertNoError(t, err)

	h1, err := hashPassword(ctx, q, "test-user", "a nice password")
	if err != nil {
		t.Fatal("unexpected error:", err)
	}

	h2, err := hashPassword(ctx, q, "another-user", "a nice password")
	if err != nil {
		t.Fatal("unexpected error:", err)
	}

	if h1 == h2 {
		t.Error("did not expect equal hashes")
	}
}

func TestAuthProvider(t *testing.T) {
	t.Skip("not yet")
}
