package query

import (
	"context"
	"database/sql"
)

type TXFunc func(q *Queries) error

type BeginTxer interface {
	BeginTx(context.Context, *sql.TxOptions) (*sql.Tx, error)
}

func (q *Queries) Raw() DBTX {
	return q.db
}

func (q *Queries) RunTx(ctx context.Context, txf TXFunc) (err error) {
	db := q.db.(BeginTxer)

	var tx *sql.Tx

	tx, err = db.BeginTx(ctx, nil)
	if err != nil {
		return err
	}

	defer func() {
		if err != nil {
			tx.Rollback()
			return
		}

		err = tx.Commit()
	}()

	err = txf(q.WithTx(tx))
	if err != nil {
		return err
	}

	return nil
}
