{{ template "base" . }}

{{ define "title" }}Details for {{ .Wine.Name }}{{ end }}

{{ define "header-left" }}
	<a class="pure-button" href="/"><i class="fas fa-arrow-left"></i> Back</a>
{{ end }}

{{ define "content" }}
<form class="pure-form pure-form-aligned" enctype="multipart/form-data" method="POST">
	{{ template "header" . }}

	<div class="content withfooter details pure-u-1">
		<div class="maxwidth box">
			<input type="hidden" name="id" value="{{ .Wine.WineID }}">

			<fieldset>
				<div  class="pure-control-group">
					<label for="form-name">Name</label>
					{{ if .User.CanWrite }}
						<input id="form-name" type="text" name="name" value="{{ .Wine.Name }}" placeholder="Name">
					{{ else }}
						<span id="form-name">{{ .Wine.Name }}</span>
					{{ end }}
				</div>

				<div  class="pure-control-group">
					<label for="form-rating">Rating</label>
					{{ if .User.CanWrite }}
						<input id="form-rating" type="number" name="rating" value="{{ .Wine.Rating.Int32 }}" placeholder="Rating">
					{{ else }}
						<span id="form-rating">{{ .Wine.Rating.Int32 }}</span>
					{{ end }}
				</div>

				<div class="pure-control-group">
					<label for="form-country">
						Country (<a href="https://en.wikipedia.org/wiki/List_of_ISO_3166_country_codes#Current_ISO_3166_country_codes" target="_blank">ISO 3166 Alpha-2</a>)
					</label>
					{{ if .User.CanWrite }}
						<input id="form-country" type="text" name="country" value="{{ .Wine.Country.String }}" placeholder="XX" pattern="[A-Za-z]{2}">
					{{ else }}
						<span id="form-country">{{ .Wine.Country.String }}</span>
					{{ end }}

					{{ if .Wine.Country.Valid }}
						<img src="/static/flags/{{ .Wine.Country.String }}.png"
						     alt="Country flag of {{ .Wine.Country.String }}">
					{{ end }}
				</div>

				{{ if .User.CanWrite }}
				<div class="pure-control-group">
					<label for="form-new-picture">New picture</label>
					<input id="form-new-picture" type="file" name="picture" accept="image/png, image/jpeg">
					<!-- TODO: add a button to remove the image -->
				</div>

				<div class="pure-control-group">
					<label for="form-new-comment">Add comment</label>
					<textarea id="form-new-comment" name="comment" placeholder="Etaoin Shrdlu"></textarea>
				</div>
				{{ end }}
			</fieldset>

			{{ if .Comments }}
			<details open>
				<summary>Comments</summary>
				<ul>
					{{ range .Comments }}
					<li class="comment">
						{{ if $.User.CanWrite }}
						<button type="submit"
							name="action"
							value="delete-comment-{{ .CommentID }}"
							class="pure-button button-warning small">
							<i class="fas fa-trash-alt"></i>
						</button>
						{{ end }}
						{{ .Content }}
					</li>
					{{ end }}
				</ul>
			</details>
			{{ end }}

			{{ if .Wine.HasPicture }}
			<img class="foto pure-img" src="/details/img/{{ .Wine.WineID }}"
			     alt="A photograph of a bottle of wine labelled '{{ .Wine.Name }}'"/>
			{{ end }}
		</div>
	</div>

	<footer class="small pure-u-1">
		<div class="maxwidth box">
			{{ if .User.CanWrite }}
			<button type="submit" name="action" value="save" class="pure-button pure-button-primary">
				<i class="fas fa-save"></i>
				Save Changes
			</button>
			<button type="submit" name="action" value="delete" class="right pure-button button-warning">
				<i class="fas fa-trash-alt"></i>
				Delete
			</button>
			{{ end }}
		</div>
	</footer>
</form>
{{ end }}